==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDescriptionMetadata } from "./WebCancelableEventArgsDescriptionMetadata";
import { WebCancelableBrowserEventArgsDescription } from "./WebCancelableBrowserEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDescriptionMetadata.c(WebCancelableBrowserEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebCancelableBrowserEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDescriptionMetadata.b(a);
            a.aa("WebCancelableBrowserEventArgs", () => new WebCancelableBrowserEventArgsDescription());
            a.z("WebCancelableBrowserEventArgs", WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableBrowserEventArgsDescriptionMetadata, 'WebCancelableBrowserEventArgsDescriptionMetadata');
    WebCancelableBrowserEventArgsDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDescriptionMetadata } from "./WebCancelableEventArgsDescriptionMetadata";
import { WebCancelableBrowserEventArgsDescription } from "./WebCancelableBrowserEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDescriptionMetadata.c(WebCancelableBrowserEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCancelableBrowserEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDescriptionMetadata.b(a);
            a.ac("WebCancelableBrowserEventArgs", () => new WebCancelableBrowserEventArgsDescription());
            a.ab("WebCancelableBrowserEventArgs", WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableBrowserEventArgsDescriptionMetadata, 'WebCancelableBrowserEventArgsDescriptionMetadata');
    WebCancelableBrowserEventArgsDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDescriptionMetadata;
})();
